from datazen.load import load_dir as load_dir
from typing import Dict, List

def load(directories: List[str], variable_data: dict = ..., loaded_list: List[str] = ..., hashes: Dict[str, dict] = ...) -> dict: ...
