from datazen.paths import get_file_ext as get_file_ext
from typing import Any, List, TextIO, Tuple

LOG: Any

def get_json_data(data_file: TextIO) -> Tuple[dict, bool]: ...
def get_yaml_data(data_file: TextIO) -> Tuple[dict, bool]: ...
def load_stream(data_stream: TextIO, data_path: str) -> Tuple[dict, bool]: ...
def dedup_dict_lists(data: dict) -> dict: ...
def merge_dicts(dicts: List[dict], expect_overwrite: bool = ...) -> dict: ...
def merge(dict_a: dict, dict_b: dict, path: List[str] = ..., expect_overwrite: bool = ...) -> dict: ...
def load(data_path: str, variables: dict, dict_to_update: dict, expect_overwrite: bool = ..., is_template: bool = ...) -> Tuple[dict, bool]: ...
def get_hash(data: str, encoding: str = ...) -> str: ...
def get_file_hash(path: str) -> str: ...
def set_file_hash(hashes: dict, path: str, set_new: bool = ...) -> bool: ...
